:math:`x(t) \longleftrightarrow X(s)`

:math:`x(a t) \longleftrightarrow \frac{X(\frac{s}{a})}{\left|{a}\right|}`

:math:`x(t - \tau) \longleftrightarrow X(s) e^{- s \tau}`

:math:`\cos{\left(2 \pi f_{0} t \right)} \longleftrightarrow \frac{s}{4 \pi^{2} f_{0}^{2} + s^{2}}`

:math:`\sin{\left(2 \pi f_{0} t \right)} \longleftrightarrow \frac{2 \pi f_{0}}{4 \pi^{2} f_{0}^{2} + s^{2}}`

:math:`e^{2 \mathrm{j} \pi f_{0} t} \longleftrightarrow \frac{1}{s \left(- \frac{2 \mathrm{j} \pi f_{0}}{s} + 1\right)}`

:math:`1 \longleftrightarrow \frac{1}{s}`

:math:`t \longleftrightarrow \frac{1}{s^{2}}`

:math:`t^{2} \longleftrightarrow \frac{2}{s^{3}}`

:math:`\delta\left(t\right) \longleftrightarrow 1`

:math:`\delta\left(t - t_{0}\right) \longleftrightarrow e^{- s t_{0}}`

:math:`u\left(t\right) \longleftrightarrow \frac{1}{s}`

:math:`t u\left(t\right) \longleftrightarrow \frac{1}{s^{2}}`

:math:`\mathrm{sign}{\left(t \right)} \longleftrightarrow \frac{1}{s}`

:math:`e^{- \left|{t}\right|} \longleftrightarrow \frac{1}{s + 1}`

:math:`e^{- t} u\left(t\right) \longleftrightarrow \frac{1}{s + 1}`

